==> dl.php?src=linea21_1_3_1.zip: linea21/languages/it/define.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage it
 * @author Alessandra Rossi & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

$l10n_links = array ('it' => array(
    					'home'=> array ('linkvalue' => 'home', 'accesskey' => '1', 'title' => 'home', 'desc'=>'accedi alla home page', 'alias'=> false, 'template'=>'home'),
    					'project'=> array ('linkvalue' => 'progetto', 'accesskey' => 'a', 'title' => 'progetti', 'desc'=>'progetti d\'azione sostenibile', 'alias'=> false, 'template'=>'publication'), 
    					'project-archives'=> array ('linkvalue' => 'progetto-archivi', 'title' => 'progetti', 'desc'=>'progetti d\'azione sostenibile', 'alias'=> 'project', 'template'=>'publication'), 
    					'news'=> array ('linkvalue' => 'news', 'accesskey' => 'n', 'title' => 'news', 'desc'=>'news del vostro comune', 'alias'=> false, 'template'=>'publication'), 
    					'news-archives'=> array ('linkvalue' => 'news-archivi', 'title' => 'news - archivi', 'desc'=>'archivi delle news del vostro comune', 'alias'=> 'news', 'template'=>'publication'),
    					'report'=> array ('linkvalue' => 'rapporto', 'title' => 'rapporti dei gruppi di lavoro', 'desc'=>'consulta il rapporto del gruppo di lavoro', 'alias'=> 'workgroup', 'template'=>'publication'),
    					'report-part'=> array ('linkvalue' => 'rapporto-sezione', 'title' => 'dettagli rapporto del gruppo di lavoro', 'desc'=>'consulta la sezione del rapporto del gruppo di lavoro', 'alias'=> 'workgroup', 'template'=>'publication'),
    					'directory'=> array ('linkvalue' => 'rubrica', 'accesskey' => 'y', 'title' => 'rubrica', 'desc'=>'rubrica degli esperti di ambiente/sviluppo sostenibile', 'alias'=> false, 'template'=>'yellowpages'),
    					'directory-detail'=> array ('linkvalue' => 'rubrica-dettagli', 'title' => 'rubrica', 'desc'=>'rubrica degli esperti di ambiente/sviluppo sostenibile', 'alias'=> 'directory', 'template'=>'yellowpages'),
    					'directory-add'=> array ('linkvalue' => 'rubrica-aggiunta', 'title' => 'rubrica', 'desc'=>'rubrica degli esperti di ambiente/sviluppo sostenibile', 'alias'=> 'directory', 'template'=>'yellowpages'),
    					'workgroup'=> array ('linkvalue' => 'gruppo-di-lavoro', 'accesskey' => 'w', 'title' => 'gruppi di lavoro', 'desc'=>'accedi e partecipa ai gruppi di lavoro', 'alias'=> false, 'template'=>'workshop'), 
    					'subscribe-workgroup'=> array ('linkvalue' => 'iscrizione-gruppo-di-lavoro', 'title' => 'gruppi di lavoro', 'desc'=>'Iscriviti a un gruppo di lavoro', 'alias'=> 'workgroup', 'template'=>'workshop'), 
    					'calendar'=> array ('linkvalue' => 'calendario', 'title' => 'calendario del gruppo di lavoro', 'desc'=>'calendario del gruppo di lavoro', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic-list'=> array ('linkvalue' => 'discussione-lista', 'title' => 'discussioni del gruppo di lavoro', 'desc'=>'discussioni del gruppo di lavoro', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic'=> array ('linkvalue' => 'discussione', 'title' => 'argomento di discussione del gruppo di lavoro', 'desc'=>'argomento di discussione del gruppo di lavoro', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'post-update'=> array ('linkvalue' => 'messaggio-edizione', 'title' => 'edizione del messaggio', 'desc'=>'edizione del messaggio', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic-add'=> array ('linkvalue' => 'aggiunta-discussione', 'title' => 'aggiunta una discussione', 'desc'=>'aggiunta una discussione', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'post-add'=> array ('linkvalue' => 'aggiunta-messaggio', 'title' => 'aggiunta un messaggio', 'desc'=>'aggiunta un messaggio', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'publication'=> array ('linkvalue' => 'pubblicazione', 'accesskey' => 'p', 'title' => 'pubblicazioni', 'desc'=>'accedi alle pubblicazioni tematiche', 'alias'=> false, 'template'=>'publication'),
    					'publication-archives'=> array ('linkvalue' => 'pubblicazione-archivi', 'title' => 'pubblicazioni', 'desc'=>'accedi agli archivi delle pubblicazioni tematiche', 'alias'=> 'publication', 'template'=>'publication'),
    					'publication-part'=> array ('linkvalue' => 'pubblicazione-parte', 'title' => 'pubblicazioni', 'desc'=>'accedi in dettaglio alla pubblicazione tematica', 'alias'=> 'publication', 'template'=>'publication'),
    					'dashboard'=> array ('linkvalue' => 'pannello-di-controllo', 'accesskey' => 'd', 'title' => 'pannello di controllo', 'desc'=>'lo stato degli indicatori', 'alias'=> false, 'template'=>'dashboard'),  
                        'dashboard-rules'=> array ('linkvalue' => 'pannello-di-controllo-regolamentazione', 'title' => 'regolamentazione dell\'indicatore', 'desc'=>'regolamentazione dell\'indicatore', 'alias'=> 'dashboard', 'template'=>'dashboard'),  
                        'dashboard-assessment'=> array ('linkvalue' => 'pannello-di-controllo-valutazione', 'title' => 'criteri di valutazione', 'desc'=>'criteri di valutazione', 'alias'=> 'dashboard', 'template'=>'dashboard'),  
                        'dashboard-provider'=> array ('linkvalue' => 'pannello-di-controllo-fornitore', 'title' => 'fornitore dell\'indicatore', 'desc'=>'fornitore dell\'indicatore', 'alias'=> 'dashboard', 'template'=>'dashboard'),
    					'user-prefs'=> array ('linkvalue' => 'preferenze-utente', 'accesskey' => 'u', 'title' => 'preferenze utenti', 'desc'=>'accedi alle tue preferenze utenti', 'alias'=> false, 'template'=>'user'),
    					'logout'=> array ('linkvalue' => 'disconnetti', 'accesskey' => 'l','title' => 'disconnetti', 'desc'=>'disconnetti', 'alias'=> false, 'template'=>'user'),
    					'user-registration'=> array ('linkvalue' => 'iscrizione-utente', 'accesskey' => 'c', 'title' => 'iscrizione utente', 'desc'=>'crea il tuo account', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'user-profile'=> array ('linkvalue' => 'profilo-utente', 'title' => 'profilo utente', 'desc'=>'consulta il profilo dell\'utente', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'search'=> array ('linkvalue' => 'ricerca', 'accesskey' => '4', 'title' => 'effettua una ricerca avanzata', 'desc'=>'ricerca avanzata', 'alias'=> false, 'template'=>'search'),
    					'search-result'=> array ('linkvalue' => 'risultati-ricerca', 'title' => 'risultati della ricerca', 'desc'=>'risultati della ricerca', 'alias'=> 'search', 'template'=>'search'),
    					'accessibility'=> array ('linkvalue' => 'accessibilita', 'accesskey' => '0', 'title' => 'Carta d\'accessibilità Linea21', 'desc'=>'documento di accessibilità Linea21', 'alias'=> false, 'template'=>'accessibility'),
    					'report-all'=> array ('linkvalue' => 'listarapporti', 'title' => 'rapporti del gruppo di lavoro', 'desc'=>'rapporti del gruppo di lavoro', 'alias'=> 'workgroup', 'template'=>'workshop'),  
                        'user-all'=> array ('linkvalue' => 'listautenti', 'title' => 'utenti del gruppo di lavoro', 'desc'=>'utenti del gruppo di lavoro', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'subscribe-newsletter'=> array ('linkvalue' => 'abbonnamento-newsletter', 'title' => 'abbonnati alla newsletter', 'desc'=>'abbonnati alla newsletter', 'alias'=> false, 'template'=>'message'),
    					'css-switch'=> array ('linkvalue' => 'cambia-stile', 'title' => 'cambia stile e impaginazione', 'desc'=>'cambia stile e impaginazione', 'alias'=> false, 'template'=>'message')
));

$l10n_filters = array ('it' => array(
    						'level' => array('linkvalue' => 'livello', 'name' => 'livello', 'desc'=>'filtrare per livello', 'active' => 0),
    						'theme' => array('linkvalue' => 'tema', 'name' => 'tema', 'desc'=>'filtrare per tema', 'active' => 0),
                        	'priority' => array('linkvalue' => 'priorita', 'name' => 'priorità', 'desc'=>'filtrare per priorità', 'active' => 0),
    						'scale' => array('linkvalue' => 'scala', 'name' => 'scala', 'desc'=>'filtrare per scala', 'active' => 0),
                            'alpha' => array('linkvalue' => 'alpha', 'name' => 'alpha', 'desc'=>'filtrare per ordine alfabetico', 'active' => 0)
));
?>

==> dl.php?src=linea21_1_4.zip: linea21/languages/it/define.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage it
 * @author Alessandra Rossi & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

$culture = array( 'it' => array( 'Language' => 'Italiano'));

$l10n_links = array ('it' => array(
    					'home'=> array ('linkvalue' => 'home', 'accesskey' => '1', 'title' => 'home', 'desc'=>'accedi alla home page', 'alias'=> false, 'template'=>'home'),
    					'project'=> array ('linkvalue' => 'progetto', 'accesskey' => 'a', 'title' => 'progetti', 'desc'=>'progetti d\'azione sostenibile', 'alias'=> false, 'template'=>'publication'),
    					'project-archives'=> array ('linkvalue' => 'progetto-archivi', 'title' => 'progetti', 'desc'=>'progetti d\'azione sostenibile', 'alias'=> 'project', 'template'=>'publication'),
    					'news'=> array ('linkvalue' => 'news', 'accesskey' => 'n', 'title' => 'news', 'desc'=>'news', 'alias'=> false, 'template'=>'publication'),
    					'news-archives'=> array ('linkvalue' => 'news-archivi', 'title' => 'news - archivi', 'desc'=>'archivi delle news', 'alias'=> 'news', 'template'=>'publication'),
    					'report'=> array ('linkvalue' => 'rapporto', 'title' => 'rapporti dei gruppi di lavoro', 'desc'=>'consulta il rapporto del gruppo di lavoro', 'alias'=> 'workgroup', 'template'=>'publication'),
    					'report-part'=> array ('linkvalue' => 'rapporto-sezione', 'title' => 'dettagli rapporto del gruppo di lavoro', 'desc'=>'consulta la sezione del rapporto del gruppo di lavoro', 'alias'=> 'workgroup', 'template'=>'publication'),
    					'directory'=> array ('linkvalue' => 'rubrica', 'accesskey' => 'y', 'title' => 'rubrica', 'desc'=>'rubrica degli esperti di ambiente/sviluppo sostenibile', 'alias'=> false, 'template'=>'yellowpages'),
    					'directory-detail'=> array ('linkvalue' => 'rubrica-dettagli', 'title' => 'rubrica', 'desc'=>'rubrica degli esperti di ambiente/sviluppo sostenibile', 'alias'=> 'directory', 'template'=>'yellowpages'),
    					'directory-add'=> array ('linkvalue' => 'rubrica-aggiunta', 'title' => 'rubrica', 'desc'=>'rubrica degli esperti di ambiente/sviluppo sostenibile', 'alias'=> 'directory', 'template'=>'yellowpages'),
    					'workgroup'=> array ('linkvalue' => 'gruppo-di-lavoro', 'accesskey' => 'w', 'title' => 'gruppi di lavoro', 'desc'=>'accedi e partecipa ai gruppi di lavoro', 'alias'=> false, 'template'=>'workshop'),
    					'workgroup-subscription'=> array ('linkvalue' => 'iscrizione-gruppo-di-lavoro',  'accesskey' => 's', 'title' => 'Iscriviti a un gruppo di lavoro', 'desc'=>'Iscriviti a un gruppo di lavoro', 'alias'=> false, 'template'=>'wg-subscription'),
    					'files'=> array ('linkvalue' => 'shared-files', 'title' => 'Access to shared files', 'desc'=>'Access to shared files', 'alias'=> 'workgroup', 'template'=>'workshop'), // @todo translate
    					'calendar'=> array ('linkvalue' => 'calendario', 'title' => 'calendario del gruppo di lavoro', 'desc'=>'calendario del gruppo di lavoro', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic-list'=> array ('linkvalue' => 'discussione-lista', 'title' => 'discussioni del gruppo di lavoro', 'desc'=>'discussioni del gruppo di lavoro', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic'=> array ('linkvalue' => 'discussione', 'title' => 'argomento di discussione del gruppo di lavoro', 'desc'=>'argomento di discussione del gruppo di lavoro', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'post-update'=> array ('linkvalue' => 'messaggio-edizione', 'title' => 'edizione del messaggio', 'desc'=>'edizione del messaggio', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic-add'=> array ('linkvalue' => 'aggiunta-discussione', 'title' => 'aggiunta una discussione', 'desc'=>'aggiunta una discussione', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'post-add'=> array ('linkvalue' => 'aggiunta-messaggio', 'title' => 'aggiunta un messaggio', 'desc'=>'aggiunta un messaggio', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'publication'=> array ('linkvalue' => 'pubblicazione', 'accesskey' => 'p', 'title' => 'pubblicazioni', 'desc'=>'accedi alle pubblicazioni tematiche', 'alias'=> false, 'template'=>'publication'),
    					'publication-archives'=> array ('linkvalue' => 'pubblicazione-archivi', 'title' => 'pubblicazioni', 'desc'=>'accedi agli archivi delle pubblicazioni tematiche', 'alias'=> 'publication', 'template'=>'publication'),
    					'publication-part'=> array ('linkvalue' => 'pubblicazione-parte', 'title' => 'pubblicazioni', 'desc'=>'accedi in dettaglio alla pubblicazione tematica', 'alias'=> 'publication', 'template'=>'publication'),
    					'dashboard'=> array ('linkvalue' => 'pannello-di-controllo', 'accesskey' => 'd', 'title' => 'pannello di controllo', 'desc'=>'lo stato degli indicatori', 'alias'=> false, 'template'=>'dashboard'),
                        'dashboard-rules'=> array ('linkvalue' => 'pannello-di-controllo-regolamentazione', 'title' => 'regolamentazione dell\'indicatore', 'desc'=>'regolamentazione dell\'indicatore', 'alias'=> 'dashboard', 'template'=>'dashboard'),
                        'dashboard-assessment'=> array ('linkvalue' => 'pannello-di-controllo-valutazione', 'title' => 'criteri di valutazione', 'desc'=>'criteri di valutazione', 'alias'=> 'dashboard', 'template'=>'dashboard'),
                        'dashboard-provider'=> array ('linkvalue' => 'pannello-di-controllo-fornitore', 'title' => 'fornitore dell\'indicatore', 'desc'=>'fornitore dell\'indicatore', 'alias'=> 'dashboard', 'template'=>'dashboard'),
    					'user-prefs'=> array ('linkvalue' => 'preferenze-utente', 'accesskey' => 'u', 'title' => 'preferenze utenti', 'desc'=>'accedi alle tue preferenze utenti', 'alias'=> false, 'template'=>'user'),
    					'logout'=> array ('linkvalue' => 'disconnetti', 'accesskey' => 'l','title' => 'disconnetti', 'desc'=>'disconnetti', 'alias'=> false, 'template'=>'user'),
    					'user-registration'=> array ('linkvalue' => 'iscrizione-utente', 'accesskey' => 'c', 'title' => 'iscrizione utente', 'desc'=>'crea il tuo account', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'user-profile'=> array ('linkvalue' => 'profilo-utente', 'title' => 'profilo utente', 'desc'=>'consulta il profilo dell\'utente', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'forgot-password'=> array ('linkvalue' => 'forgot-password', 'title' => 'Forgot your password?', 'desc'=>'Change your password', 'alias'=> 'user-prefs', 'template'=>'user'), // @todo translation
    					'search'=> array ('linkvalue' => 'ricerca', 'accesskey' => '4', 'title' => 'effettua una ricerca avanzata', 'desc'=>'ricerca avanzata', 'alias'=> false, 'template'=>'search'),
    					'search-result'=> array ('linkvalue' => 'risultati-ricerca', 'title' => 'risultati della ricerca', 'desc'=>'risultati della ricerca', 'alias'=> 'search', 'template'=>'search'),
    					'accessibility'=> array ('linkvalue' => 'accessibilita', 'accesskey' => '0', 'title' => 'Carta d\'accessibilità Linea21', 'desc'=>'documento di accessibilità Linea21', 'alias'=> false, 'template'=>'accessibility'),
    					'report-all'=> array ('linkvalue' => 'listarapporti', 'title' => 'rapporti del gruppo di lavoro', 'desc'=>'rapporti del gruppo di lavoro', 'alias'=> 'workgroup', 'template'=>'workshop'),
                        'user-all'=> array ('linkvalue' => 'listautenti', 'title' => 'utenti del gruppo di lavoro', 'desc'=>'utenti del gruppo di lavoro', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'subscribe-newsletter'=> array ('linkvalue' => 'abbonnamento-newsletter', 'title' => 'abbonnati alla newsletter', 'desc'=>'abbonnati alla newsletter', 'alias'=> false, 'template'=>'message'),
    					'css-switch'=> array ('linkvalue' => 'cambia-stile', 'title' => 'cambia stile e impaginazione', 'desc'=>'cambia stile e impaginazione', 'alias'=> false, 'template'=>'message'),
                        'contact'=> array ('linkvalue' => 'contattaci', 'accesskey' => 'z', 'title' => 'contattaci', 'desc'=>'contattaci', 'alias'=> false, 'template'=>'message') // @todo translation
));

$l10n_filters = array ('it' => array(
    						'level' => array('linkvalue' => 'livello', 'name' => 'livello', 'desc'=>'filtrare per livello', 'active' => 0),
    						'theme' => array('linkvalue' => 'tema', 'name' => 'tema', 'desc'=>'filtrare per tema', 'active' => 0),
                        	'priority' => array('linkvalue' => 'priorita', 'name' => 'priorità', 'desc'=>'filtrare per priorità', 'active' => 0),
    						'scale' => array('linkvalue' => 'scala', 'name' => 'scala', 'desc'=>'filtrare per scala', 'active' => 0),
                            'alpha' => array('linkvalue' => 'alpha', 'name' => 'alpha', 'desc'=>'filtrare per ordine alfabetico', 'active' => 0)
));
?>
